@@ -74,12 +74,12 @@ fit.bayes.MSGARCH_SPEC <- function(spec, y, ctr = list()) {
   y <- f.check.y(y)
   l.ctr <- f.process.ctr(ctr)
   if (is.null(l.ctr$theta0)) {
-    if (isTRUE(ctr$do.enhance.theta0)) {
-      l.ctr$theta0 <- f.enhance.theta(spec = spec, theta = spec$theta0, y = y)
-    } else {
-      l.ctr$theta0 <- spec$theta0
-    }
+    l.ctr$theta0 <- spec$theta0
   }
+  if (isTRUE(ctr$do.enhance.theta0)) {
+    l.ctr$theta0 <- f.enhance.theta(spec = spec, theta = l.ctr$theta0, y = y)
+  }
+  
   f.kernel <- function(x, log = TRUE) {
     name <- spec$name
     unique.spec <- unique(name, FALSE)
@@ -94,9 +94,9 @@ fit.bayes.MSGARCH_SPEC <- function(spec, y, ctr = list()) {
       } else {
         if (length(unc.vol) != 1) {
           for (j in 1:(length(unc.vol) - 1)) {
-          if (unc.vol[j] > unc.vol[j + 1]) {
-            return(-1e+10)
-          }
+            if (unc.vol[j] > unc.vol[j + 1]) {
+              return(-1e+10)
+            }
           }
         }
       }
