@@ -6,7 +6,7 @@
 #' @param x Vector (of size N) of point at \code{t = T + 1} to be evaluated (used when \code{do.its = FALSE}).
 #' @param theta Vector (of size d) or matrix (of size M x d) of parameter estimates (not require when using a fit object).
 #' @param y  Vector (of size T) of observations (not require when using a fit object).
-#' @param log  Boolean indicating if the log-density is returned. (Default: \code{log = TRUE})
+#' @param log  Boolean indicating if the log-density is returned. (Default: \code{log = FALSE})
 #' @param do.its  Boolean indicating if the in-sample predictive is returned. (Default: \code{do.its = FALSE})
 #' @details If a matrix of MCMC posterior draws estimates is given, the Bayesian Probability integral transform is calculated.
 #' If \code{do.its = FALSE}, the points \code{x} are evaluated as \code{t = T + 1} realization and the method uses the variance estimate at \code{t = T + 1}.
@@ -44,12 +44,12 @@
 #' }
 #'The class \code{MSGARCH_PRED} contains the \code{plot} method only if \code{do.its = FALSE}.
 #' @export
-pred <- function(object, x, theta, y, log = TRUE, do.its = FALSE) {
+pred <- function(object, x, theta, y, log = FALSE, do.its = FALSE) {
   UseMethod("pred", object)
 }
 
 #' @export
-pred.MSGARCH_SPEC <- function(object, x = NULL, theta, y, log = TRUE, do.its = FALSE) {
+pred.MSGARCH_SPEC <- function(object, x = NULL, theta = NULL, y = NULL, log = FALSE, do.its = FALSE) {
   y <- f.check.y(y)
   N <- nrow(theta)
   if (isTRUE(do.its)) {
@@ -60,30 +60,29 @@ pred.MSGARCH_SPEC <- function(object, x = NULL, theta, y, log = TRUE, do.its = F
   }
   tmp <- matrix(data = NA, nrow = N, ncol = nx)
   for (i in 1:N) {
-    tmp[i, ] <- MSGARCH::pdf(object, x, theta = theta[i, ], y = y, log = FALSE,
-                            do.its = do.its)$pdf
+    tmp[i, ] <- MSGARCH::pdf(object, x, theta = theta[i, ], y = y, log = FALSE, do.its = do.its)$pdf
   }
   tmp <- colMeans(tmp, na.rm = TRUE)
-  if (log) {
+  if (isTRUE(log)) {
     tmp <- log(tmp)
   }
   out <- list()
-  out$pred <- tmp
-  out$x <- x
+  out$pred   <- tmp
+  out$x      <- x
   out$do.its <- do.its
   class(out) <- "MSGARCH_PRED"
   return(out)
 }
 
 #' @export
-pred.MSGARCH_MLE_FIT <- function(object, x = NULL, theta = NULL, y = NULL, log = TRUE,
+pred.MSGARCH_MLE_FIT <- function(object, x = NULL, theta = NULL, y = NULL, log = FALSE,
                                 do.its = FALSE) {
   return(MSGARCH::pred(object = object$spec, x = x, theta = object$theta, y = object$y,
                        log = log, do.its = do.its))
 }
 
 #' @export
-pred.MSGARCH_BAY_FIT <- function(object, x = NULL, theta = NULL, y = NULL, log = TRUE,
+pred.MSGARCH_BAY_FIT <- function(object, x = NULL, theta = NULL, y = NULL, log = FALSE,
                                 do.its = FALSE) {
   return(MSGARCH::pred(object = object$spec, x = x, theta = object$theta, y = object$y,
                        log = log, do.its = do.its))
