@@ -10,6 +10,7 @@
 #' @param ES  Boolean indicating if Expected-shortfall is also calculated. (Default: \code{ES = TRUE})
 #' @param do.its  Boolean indicating if the in-sample risk estimator are returned.
 #'  (Default: \code{do.its = FALSE})
+#' @param ctr List of control parameters for VaR evaluation.
 #' @details If a matrix of MCMC posterior draws estimates is given, the Bayesian Value-at-Risk and Expected-shortfall are calculated.
 #' If \code{do.its = FALSE}, \code{x} the risk estimator at \code{t = T + 1}, the method uses the variance estimated at \code{t = T + 1}.
 #' If \code{do.its = TRUE}, The in-sample risk estimator are calculated.
@@ -22,7 +23,7 @@
 #' \item \code{y}  : Vector (of size T) of observations.
 #' }
 #' The \code{MSGARCH_RISK} contains the \code{plot} method. 
-#' The Bayesian risk estimator can take long time to calculate depending on the size of the chain.
+#' The Bayesian risk estimator can take long time to calculate depending on the size of the MCMC chain.
 #' @examples 
 #'# load data
 #'data("sp500")
@@ -43,36 +44,37 @@
 #'
 #'# Risk estimation at T + 1                     
 #'risk = MSGARCH::risk(object = fit, level = 0.95, ES = FALSE, do.its = FALSE)
-#' @importFrom stats integrate sd uniroot                    
+#' @importFrom stats integrate sd                    
 #' @export
-risk <- function(object, theta, y, level = c(0.95, 0.99), ES = TRUE, do.its = FALSE) {
+risk <- function(object, theta, y, level = c(0.95, 0.99), ES = TRUE, 
+                 do.its = FALSE, ctr = list(n.mesh = 500, tol = 1e-04, itermax = 5)) {
   UseMethod("risk", object)
 }
 
 #' @export
 risk.MSGARCH_SPEC <- function(object, theta, y, level = c(0.95, 0.99), ES = TRUE,
-  do.its = FALSE) {
-  if(isTRUE(do.its)){
+                              do.its = FALSE, ctr = list(n.mesh = 500, tol = 1e-04, itermax = 5)) {
+  if (isTRUE(do.its)) {
     y <- c(mean(y), y)
   }
-  y <- f.check.y(y)
+  y   <- f.check.y(y)
   out <- list()
-  ny <- nrow(y)
+  ny  <- nrow(y)
   if (!isTRUE(do.its)) {
     start <- ny
-    step <- -(ny - 1)
-    end <- ny
+    step  <- -(ny - 1)
+    end   <- ny
   } else {
     start <- 2
-    step <- -1
-    end <- ny - 1
+    step  <- -1
+    end   <- ny - 1
   }
-  p <- 1 - level
-  np <- length(p)
-  xmin <- min(y) - sd(y)
-  xmax <- 0
-  itermax <- 100
-  tol <- 1e-05
+  p       <- 1 - level
+  np      <- length(p)
+  xmin    <- min(y) - sd(y)
+  xmax    <- 0
+  itermax <- ctr$itermax
+  tol     <- ctr$tol
   tmp.VaR <- NULL
   out$VaR <- matrix(data = NA, nrow = end - start + 1, ncol = np)
   if (isTRUE(ES)) {
@@ -80,11 +82,11 @@ risk.MSGARCH_SPEC <- function(object, theta, y, level = c(0.95, 0.99), ES = TRUE
   }
   for (v in start:end) {
     f.pdf <- function(x) {
-      out <- MSGARCH::pred(object, x, theta, y[1:v], log = FALSE)$pred
+      out <- MSGARCH::pred(object, x, theta, y[1:v], log = FALSE, do.its = FALSE)$pred
       return(out)
     }
     # gross approximation for VaR
-    x <- seq(from = xmin, to = xmax, length.out = 1000)
+    x <- seq(from = xmin, to = xmax, length.out = ctr$n.mesh)
     cumul <- cumsum(f.pdf(x) * (x[2] - x[1]))
     for (i in 1:np) {
       tmp.VaR[i] <- x[which.min(abs(cumul - p[i]))]
@@ -93,35 +95,35 @@ risk.MSGARCH_SPEC <- function(object, theta, y, level = c(0.95, 0.99), ES = TRUE
     for (i in 1:np) {
       p_i <- p[i]
       calc.step <- function(V) {
-        PDF <- MSGARCH::pred(object, x = V, theta = theta, y = y[1:v], log = F)$pred
-        CDF <- MSGARCH::pit(object, x = V, theta = theta, y = y[1:v])$pit
-        lPDF <- log(PDF)
-        err <- p_i - CDF
+        lPDF <- MSGARCH::pred(object, x = V, theta = theta, y = y[1:v], log = TRUE, do.its = FALSE)$pred
+        CDF  <- MSGARCH::pit(object, x = V, theta = theta, y = y[1:v], do.norm = FALSE, do.its = FALSE)$pit
+        err  <- p_i - CDF
         step <- err * exp(-lPDF)
-        return(list(step = step, err = abs(err)))
+        out  <- list(step = step, err = abs(err))
+        return(out)
       }
       # Starting values
       VaR <- tmp.VaR[i]
       # VaR calculation
       newStep <- calc.step(VaR)
-      delta <- newStep$step
-      VaR <- VaR + delta
-      covERR <- newStep$err
+      delta   <- newStep$step
+      VaR     <- VaR + delta
+      covERR  <- newStep$err
       for (j in 1:itermax) {
         if (covERR < tol) {
           break
         }
         newStep <- calc.step(VaR)
-        delta <- newStep$step
-        VaR <- VaR + delta
-        covERR <- newStep$err
+        delta   <- newStep$step
+        VaR     <- VaR + delta
+        covERR  <- newStep$err
       }
       out$VaR[v + step, i] <- VaR
     }
     if (isTRUE(ES)) {
       for (i in 1:np) {
         f.condMean <- function(x) {
-          out <- x * MSGARCH::pred(object, x, theta, y[1:v], log = FALSE)$pred
+          out <- x * MSGARCH::pred(object, x, theta, y[1:v], log = FALSE, do.its = FALSE)$pred
           return(out)
         }
         out$ES[v + step, i] <- integrate(f.condMean, lower = -Inf, upper = out$VaR[v + step, i], 
@@ -131,7 +133,7 @@ risk.MSGARCH_SPEC <- function(object, theta, y, level = c(0.95, 0.99), ES = TRUE
   }
   out$y <- y[2:length(y)]
   colnames(out$VaR) <- level
-  if(isTRUE(do.its)){
+  if (isTRUE(do.its)) {
     out$VaR <- rbind(NA, out$VaR)
     if (isTRUE(ES)) {
       out$ES <- rbind(NA, out$ES)
@@ -146,14 +148,14 @@ risk.MSGARCH_SPEC <- function(object, theta, y, level = c(0.95, 0.99), ES = TRUE
 
 #' @export
 risk.MSGARCH_MLE_FIT <- function(object, theta = NULL, y = NULL, level = c(0.95, 0.99),
-                                ES = TRUE, do.its = FALSE) {
-  return(MSGARCH::risk(object = object$spec, theta = object$theta, y = object$y,
-                      level = level, ES = ES, do.its = do.its))
+                                   ES = TRUE, do.its = FALSE, ctr = list(n.mesh = 500, tol = 1e-04, itermax = 5)) {
+  return(risk.MSGARCH_SPEC(object = object$spec, theta = object$theta, y = object$y,
+                             level = level, ES = ES, do.its = do.its, ctr = ctr))
 }
 
 #' @export
 risk.MSGARCH_BAY_FIT <- function(object, theta = NULL, y = NULL, level = c(0.95, 0.99),
-                                ES = TRUE, do.its = FALSE) {
-  return(MSGARCH::risk(object = object$spec, theta = object$theta, y = object$y,
-                       level = level, ES = ES, do.its = do.its))
+                                   ES = TRUE, do.its = FALSE, ctr = list(n.mesh = 500, tol = 1e-04, itermax = 5)) {
+  return(risk.MSGARCH_SPEC(object = object$spec, theta = object$theta, y = object$y,
+                             level = level, ES = ES, do.its = do.its, ctr = ctr))
 }
\ No newline at end of file
