@@ -18,26 +18,23 @@ unc.vol <- function(object, theta) {
 }
 
 #' @export
-unc.vol.MSGARCH_SPEC <- function(object, theta) {
+unc.vol.MSGARCH_SPEC <- function(object, theta = NULL) {
   theta <- f.check.theta(object, theta)
   for (i in 1:nrow(theta)) {
     out <- object$rcpp.func$unc_vol_Rcpp(theta, 0)
   }
   
   if(any(is.null(out))){
-    out = matrix(out, ncol = object$K,nrow = nrow(theta))
-    out = matrix(NA, nrow = nrow(out), ncol = ncol(out))
+    out = matrix(data = NA, ncol = object$K, nrow = nrow(theta))
     return(out)
   }
   
   if(any(is.na(out))){
-    out = matrix(out, ncol = object$K,nrow = nrow(theta))
-    out = matrix(NA, nrow = nrow(out), ncol = ncol(out))
+    out = matrix(data = NA, ncol = object$K,nrow = nrow(theta))
     return(out)
   } else {
     if(any(out < 0)) {
-      out = matrix(out, ncol = object$K,nrow = nrow(theta))
-      out = matrix(NA, nrow = nrow(out), ncol = ncol(out))
+      out = matrix(data = NA, ncol = object$K, nrow = nrow(theta))
       return(out)
     }
   }
